==> haskell-hslua-module-zip-1.1.3-40.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-zip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-zip
version:              1.1.3
visibility:           public
id:                   hslua-module-zip-1.1.3-Gm5qXIKNjTr7fhoIUKYp3z
key:                  hslua-module-zip-1.1.3-Gm5qXIKNjTr7fhoIUKYp3z
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file zips.
description:
    Module with function for creating, modifying, and
    extracting files from zip archives.

category:             Foreign
abi:                  e2b9c5618f3242ad4a8c6f1cfb4d2915
exposed:              True
exposed-modules:      HsLua.Module.Zip
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-module-zip-1.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-module-zip-1.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-module-zip-1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-zip
hs-libraries:         HShslua-module-zip-1.1.3-Gm5qXIKNjTr7fhoIUKYp3z
depends:
    base-4.18.2.1 bytestring-0.11.5.3 filepath-1.4.300.1
    hslua-core-2.3.2-LsuRv5joEv2BEnjW1fCbrM
    hslua-list-1.1.4-8z81DILtRHw6GXhp4f5B7Y
    hslua-marshalling-2.3.1-2wvb5zI3Ais62iyLUWMiUH
    hslua-packaging-2.3.1-CX7lhwYsgw0Jci7JtzHprm
    hslua-typing-0.1.1-4crtxjwFkdc2BMYn78fMvp text-2.0.2 time-1.12.2
    zip-archive-0.4.3.2-D5z4MdzfSf9r1oyri6gCT

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-zip/html/hslua-module-zip.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-zip/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-zip-1.1.3-41-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-zip.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-zip
version:              1.1.3
visibility:           public
id:                   hslua-module-zip-1.1.3-19AERTJjGXz8KfCei6ksZd
key:                  hslua-module-zip-1.1.3-19AERTJjGXz8KfCei6ksZd
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Lua module to work with file zips.
description:
    Module with function for creating, modifying, and
    extracting files from zip archives.

category:             Foreign
abi:                  3bd07377b5ffc6b4cb39386ba70ee50e
exposed:              True
exposed-modules:      HsLua.Module.Zip
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-module-zip-1.1.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-module-zip-1.1.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-module-zip-1.1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-zip
hs-libraries:         HShslua-module-zip-1.1.3-19AERTJjGXz8KfCei6ksZd
depends:
    base-4.18.2.1 bytestring-0.11.5.3 filepath-1.4.300.1
    hslua-core-2.3.2-6IHXwFbRgmjH5Bn36TUerg
    hslua-list-1.1.4-5xI0BhgiDrz56UbXARVZLL
    hslua-marshalling-2.3.1-Lphd68rczTTD9xcjuNYtYD
    hslua-packaging-2.3.1-4anfJzyA7OLGShitXl91KS
    hslua-typing-0.1.1-4nrS70YStomG6eM4zMy5zG text-2.0.2 time-1.12.2
    zip-archive-0.4.3.2-ICmkrWQlOHqIMrYTQRjWIn

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-zip/html/hslua-module-zip.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-zip/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
